package net.wanji.databus.po;

import com.alibaba.fastjson.annotation.JSONField;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.omg.CORBA.UNKNOWN;

import java.util.Date;

/**
 * @author duanruiming
 * @date 2023/03/10 19:02
 */
@Data
@TableName("t_cross_data_realtime")
@ApiModel(value = "CrossDataRealtimePO", description = "路口实时数据")
public class CrossDataRealtimePO {
    /**
     * 路口编号
     */
    @ApiModelProperty(value = "路口编号", notes = "")
    private String crossId;
    /**
     * 路口状态：0正常；1失衡；2拥堵；3溢出；4死锁
     */
    @ApiModelProperty(value = "路口状态：0正常；1失衡；2拥堵；3溢出；4死锁；5相位空放", notes = "")
    private Integer status;
    /**
     * 拥堵类型：1常规；2异常
     */
    @ApiModelProperty(value = "拥堵类型：1常规；2异常", notes = "")
    private Integer type;
    /**
     * 交通指数（1~10）
     */
    @ApiModelProperty(value = "交通指数（1~10）", notes = "")
    private Double trafficIndex;
    /**
     * 开始时间：yyyy-MM-dd HH;mm:ss
     */
    @ApiModelProperty(value = "开始时间：yyyy-MM-dd HH:mm:ss", notes = "")
    @JSONField(format = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date startTime;

    @ApiModelProperty(value = "结束时间：yyyy-MM-dd HH:mm:ss", notes = "")
    private Date endTime;
    @ApiModelProperty(value = "持续时间（单位：分钟）", notes = "")
    private Integer duration;
    /**
     * 是否失衡：0否；1是
     */
    @ApiModelProperty(value = "是否失衡：0否；1是", notes = "")
    private Integer isUnbalance;
    /**
     * 是否溢出：0否；1是
     */
    @ApiModelProperty(value = "是否溢出：0否；1是", notes = "")
    private Integer isSpillover;
    /**
     * 是否拥堵：0否；1是
     */
    @ApiModelProperty(value = "是否拥堵：0否；1是", notes = "")
    private Integer isCongestion;
    /**
     * 失衡指数
     */
    @ApiModelProperty(value = "失衡指数", notes = "")
    private Double unbalanceIndex;
    /**
     * 溢出指数
     */
    @ApiModelProperty(value = "溢出指数", notes = "")
    private Double spilloverIndex;
    /**
     * 拥堵指数
     */
    @ApiModelProperty(value = "拥堵指数", notes = "")
    private Double congestionIndex;
    /**
     * 路口失衡方向：1，2，3...
     */
    @ApiModelProperty(value = "路口失衡方向：1，2，3...", notes = "")
    private String unbalanceDirs;
    /**
     * 路口溢出方向：1，2，3...
     */
    @ApiModelProperty(value = "路口溢出方向：1，2，3...", notes = "")
    private String spilloverDirs;
    /**
     * 路口拥堵方向：1，2，3...
     */
    @ApiModelProperty(value = "路口拥堵方向：1，2，3...", notes = "")
    private String congestionDirs;
    /**
     * 交通流量（辆）
     */
    @ApiModelProperty(value = "交通流量（辆）", notes = "")
    private Integer flow;
    /**
     * 交通流率/h
     */
    @ApiModelProperty(value = "交通流率/h", notes = "")
    private Double flowRate;
    /**
     * 平均速度（km/h）
     */
    @ApiModelProperty(value = "平均速度（km/h）", notes = "")
    private Double speed;
    /**
     * 最大排队（米）
     */
    @ApiModelProperty(value = "最大排队（米）", notes = "")
    private Double queueLength;
    /**
     * 停车次数（次）
     */
    @ApiModelProperty(value = "停车次数（次）", notes = "")
    private Double stopTimes;
    /**
     * 延误时间（秒）
     */
    @ApiModelProperty(value = "延误时间（秒）", notes = "")
    private Integer delayTime;
    /**
     * 饱和度
     */
    @ApiModelProperty(value = "饱和度", notes = "")
    private Double sturation;
    /**
     * 采集时间（10位时间戳）
     */
    @ApiModelProperty(value = "采集时间（10位时间戳）", notes = "")
    private Integer batchTime;
    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间", notes = "")
    private Date gmtCreate;
    /**
     * 修改时间
     */
    @ApiModelProperty(value = "修改时间", notes = "")
    private Date gmtModified;
    /**
     * 红灯清空率
     */
    @ApiModelProperty(value = "红灯清空率", notes = "")
    private Double clearRate;
    /**
     * 负载均衡度
     */
    @ApiModelProperty(value = "负载均衡度", notes = "")
    private Double loadBalance;
    /**
     * 平均未清空车辆数量
     */
    @ApiModelProperty(value = "平均未清空车辆数量", notes = "")
    private Integer notClearCarNums;
    /**
     * 绿灯有效利用率
     */
    @ApiModelProperty(value = "绿灯有效利用率", notes = "")
    private Double greenLightEfficiency;
    /**
     * 溢流率
     */
    @ApiModelProperty(value = "溢流率", notes = "")
    private Double effusionRate;
    @ApiModelProperty(name = "不停车率",notes = "")
    public Double noStopRate;
    @ApiModelProperty(name = "一次停车率",notes = "")
    public Double oneStopRate;
    @ApiModelProperty(name = "二次停车率",notes = "")
    public Double twoStopRate;
    @ApiModelProperty(name = "三次停车率",notes = "")
    public Double threeStopRate;

    @ApiModelProperty(value = "非机动车流量", notes = "")
    private int nonMotorFlow;
    @ApiModelProperty(value = "85位速度（km/h）", notes = "")
    @TableField(value = "v_85")
    private double v85;
    @ApiModelProperty(value = "大车流量", notes = "")
    private int trafficFlowA;
    @ApiModelProperty(value = "中车流量", notes = "")
    private int trafficFlowB;
    @ApiModelProperty(value = "小车流量", notes = "")
    private int trafficFlowC;
    @ApiModelProperty(value = "时间占有率", notes = "")
    private double timeOccupancy;
    @ApiModelProperty(value = "空间占有率", notes = "平均空间密度（长度占比）")
    private double vehicleLengthRatioMean;
    /** add 20241123 适配神思数据 */
    @ApiModelProperty(value = "执行策略 失衡 2拥堵 3溢出 4死锁  5 空放", notes = "")
    private Integer strategy;
    @ApiModelProperty(value = "策略执行持续时间；单位：s", notes = "")
    @TableField("strategy_duration")
    private Integer strategyDuration;
    @ApiModelProperty(value = "优化执行次数", notes = "")
    @TableField("optimize_count")
    private Integer optimizeCount;
    @ApiModelProperty(value = "优化时长，单位秒", notes = "")
    @TableField("optimize_seconds")
    private Integer optimizeSeconds;
    @ApiModelProperty(value = "是否空放 0否 1是", notes = "")
    @TableField("empty_pass")
    private Integer emptyPass;
    @TableField("service_level")
    private String serviceLevel;
}
